GC_atfork_prepare

Function GC_atfork_prepare 

pub unsafe extern "C" fn GC_atfork_prepare()
Routines to handle POSIX fork() manually (no-op if handled automatically). GC_atfork_prepare() should be called immediately before fork(); GC_atfork_parent() should be invoked just after fork in the branch that corresponds to parent process (i.e., fork result is nonzero); GC_atfork_child() is to be called immediately in the child branch (i.e., fork result is 0). Note that GC_atfork_child() call should, of course, precede GC_start_mark_threads() call, if any. Note that fork() could be called from an unregistered thread.