GC_base

Function GC_base 

pub unsafe extern "C" fn GC_base(arg1: *mut c_void) -> *mut c_void
Return a pointer to the base (lowest address) of an object given a pointer to a location within the object. I.e., map an interior pointer to the corresponding base pointer. Note that with debugging allocation, this returns a pointer to the actual base of the object, i.e. the debug information, not to the base of the user object. Return NULL if displaced_pointer does not point to within a valid object. Note that a deallocated object in the garbage collected heap may be considered valid, even if it has been deallocated with GC_free() or friends.