GC_call_with_stack_base

Function GC_call_with_stack_base 

pub unsafe extern "C" fn GC_call_with_stack_base(
    arg1: GC_stack_base_func,
    arg2: *mut c_void,
) -> *mut c_void
Call a function with a stack base structure corresponding to somewhere in the GC_call_with_stack_base frame. This often can be used to provide a sufficiently accurate stack bottom. And we implement it everywhere.