GC_clear_exclusion_table

Function GC_clear_exclusion_table 

pub unsafe extern "C" fn GC_clear_exclusion_table()
Clear the number of entries in the exclusion table. Wizards only. Should be called typically with the allocator lock held, but no assertion about it by design.