GC_collect_a_little

Function GC_collect_a_little 

pub unsafe extern "C" fn GC_collect_a_little() -> c_int
Perform some garbage collection work, if appropriate. Return 0 if there is no more work to be done (including the case when garbage collection is not appropriate). Typically performs an amount of work corresponding roughly to marking from one page. May do more work if further progress requires it, e.g. if incremental collection is disabled. It is reasonable to call this in a wait loop until it returns 0. If the garbage collection is disabled but the incremental collection is already ongoing, then perform marking anyway but not stopping the world (and without the reclaim phase).