GC_deinit

Function GC_deinit 

pub unsafe extern "C" fn GC_deinit()
Perform the collector shutdown. (E.g. dispose critical sections on Windows target.) A duplicate invocation is a no-op. In case of Windows, typically, the client should also call GC_win32_free_heap() before this function call. TODO: The collector reinitialization after shutdown might work in certain configurations, but not tested.