GC_dump

Function GC_dump 

pub unsafe extern "C" fn GC_dump()
Explicitly dump the collector state. This is most often called from the debugger, or by setting the GC_DUMP_REGULARLY environment variable, but it may be useful to call it from client code during debugging. The current collection number is printed in the header of the dump. Acquires the allocator lock in the reader mode to avoid data race. Defined only if the library has been compiled without NO_DEBUGGING macro defined.