GC_dump_finalization

Function GC_dump_finalization 

pub unsafe extern "C" fn GC_dump_finalization()
Dump information about every registered disappearing link and finalizable object. Defined only if the library has been compiled without NO_DEBUGGING macro defined.