GC_dump_named

Function GC_dump_named 

pub unsafe extern "C" fn GC_dump_named(arg1: *const c_char)
The same as GC_dump but allows to specify the name of dump and does not acquire the allocator lock. If name is non-NULL, it is printed to help identifying individual dumps. Otherwise the current collection number is used as the name. Defined only if the library has been compiled without NO_DEBUGGING macro defined.