pub unsafe extern "C" fn GC_dump_regions()Expand description
Dump information about each block of every GC memory section.
Defined only if the library has been compiled without NO_DEBUGGING
macro defined.
pub unsafe extern "C" fn GC_dump_regions()Dump information about each block of every GC memory section.
Defined only if the library has been compiled without NO_DEBUGGING
macro defined.