GC_free

Function GC_free 

pub unsafe extern "C" fn GC_free(arg1: *mut c_void)
Explicitly deallocate an object. Dangerous if used incorrectly. Requires a pointer to the base of an object. An object should not be enabled for finalization (and it should not contain registered disappearing links of any kind) when it is explicitly deallocated. GC_free(0) is a no-op, as required by ANSI C for free().