GC_free_profiler_hook

Function GC_free_profiler_hook 

pub unsafe extern "C" fn GC_free_profiler_hook(arg1: *mut c_void)
A symbol to be intercepted by heap profilers so that they can accurately track allocations. Programs such as Valgrind massif and KDE heaptrack do tracking of allocated objects by overriding common allocator methods (e.g. malloc and free). However, because the collector does not work by calling standard allocation methods on objects that were reclaimed, we need a way to tell the profiler that an object has been freed. This function is not intended to be called by the client, it should be used for the interception purpose only. The collector calls this function internally whenever an object is freed. Defined only if the library has been compiled with VALGRIND_TRACKING macro defined.