GC_gcollect_and_unmap

Function GC_gcollect_and_unmap 

pub unsafe extern "C" fn GC_gcollect_and_unmap()
Same as above but ignores the default stop_func setting and tries to unmap as much memory as possible (regardless of the corresponding switch setting). The recommended usage: on receiving a system low-memory event; before retrying a system call failed because of the system is running out of resources.