GC_get_full_gc_total_ns_frac

Function GC_get_full_gc_total_ns_frac 

pub unsafe extern "C" fn GC_get_full_gc_total_ns_frac() -> c_ulong
Get the fractional nanosecond part of the total time value returned by GC_get_full_gc_total_time(). The result is always less than 1000000. In the multi-threaded mode, the client should use GC_call_with_reader_lock() to get a consistent total time value. Defined only if the library has been compiled without NO_CLOCK macro defined.