GC_get_full_gc_total_time

Function GC_get_full_gc_total_time 

pub unsafe extern "C" fn GC_get_full_gc_total_time() -> c_ulong
Get the total time of all full collections since the start of the performance measurements. Includes time spent in the supplementary actions like blacklists promotion, marks clearing, free lists reconstruction and objects finalization. The measurement unit is a millisecond. Note that the returned value wraps around on overflow. The function does not use any synchronization. Defined only if the library has been compiled without NO_CLOCK macro defined.