GC_get_heap_usage_safe

Function GC_get_heap_usage_safe 

pub unsafe extern "C" fn GC_get_heap_usage_safe(
    arg1: *mut GC_word,
    arg2: *mut GC_word,
    arg3: *mut GC_word,
    arg4: *mut GC_word,
    arg5: *mut GC_word,
)
Return the heap usage information. This is a thread-safe (atomic) alternative for the five above getters. (This function acquires the allocator lock in the reader mode, thus preventing data race and returning the consistent result.) Passing NULL pointer is allowed for any argument. Returned (filled in) values are of GC_word type.