GC_get_my_stackbottom

Function GC_get_my_stackbottom 

pub unsafe extern "C" fn GC_get_my_stackbottom(
    arg1: *mut GC_stack_base,
) -> *mut c_void
Fill in the GC_stack_base structure with the cold end (bottom) of the stack of the current thread (or coroutine). Unlike GC_get_stack_base, it retrieves the value stored in the collector (which is initially set by the collector upon the thread is started or registered manually but it could be later updated by client using GC_set_stackbottom). Returns the GC-internal non-NULL handle of the thread which could be passed to GC_set_stackbottom() later. It is assumed that the collector is already initialized and the thread is registered. Acquires the allocator lock in the reader mode.