GC_get_pages_executable

Function GC_get_pages_executable 

pub unsafe extern "C" fn GC_get_pages_executable() -> c_int
Returns nonzero value if the garbage collector is set to the allocate-executable-memory mode. The mode could be changed by GC_set_pages_executable (before GC_INIT() call) unless the former has no effect on the platform. Does not use or need synchronization.