GC_get_stack_base

Function GC_get_stack_base 

pub unsafe extern "C" fn GC_get_stack_base(
    arg1: *mut GC_stack_base,
) -> c_int
Attempt to fill in the GC_stack_base structure with the stack bottom for this thread. This appears to be required to implement anything like the JNI (Java Native Interface) AttachCurrentThread in an environment in which new threads are not automatically registered with the collector. It is also unfortunately hard to implement well on many platforms. Returns GC_SUCCESS or GC_UNIMPLEMENTED. Acquires the allocator lock on some platforms.