GC_get_supported_vdbs

Function GC_get_supported_vdbs 

pub unsafe extern "C" fn GC_get_supported_vdbs() -> c_uint
Get the list of available VDB (virtual dirty bits) techniques. The returned value is a constant one, either GC_VDB_NONE, or one or more of the above GC_VDB_ constants, or’ed together. The result is not affected by GC_set_mprotect_vdb_allowed(). May be called before the collector is initialized.