GC_incremental_protection_needs

Function GC_incremental_protection_needs 

pub unsafe extern "C" fn GC_incremental_protection_needs() -> c_int
Does incremental mode write-protect pages in a client-visible way? Returns zero or more of the above GC_PROTECTS_ constants, or’ed together. The collector is assumed to be initialized before this call. The result is not affected by GC_set_manual_vdb_allowed(). Call of GC_enable_incremental() may change the result to GC_PROTECTS_NONE if some VDB implementation chosen at runtime is not needing to write-protect the pages (thus GC_set_mprotect_vdb_allowed(0) might affect the result).