GC_invoke_finalizers

Function GC_invoke_finalizers 

pub unsafe extern "C" fn GC_invoke_finalizers() -> c_int
Run finalizers for all objects that are ready to be finalized. Return the number of finalizers that were run. Normally this is also called implicitly during some allocations. If GC_finalize_on_demand is nonzero, it must be called explicitly.