GC_is_valid_displacement

Function GC_is_valid_displacement 

pub unsafe extern "C" fn GC_is_valid_displacement(
    arg1: *mut c_void,
) -> *mut c_void
Check that if p is a pointer to a heap page, then it points to a valid displacement within a heap object. If it is not, invoke GC_is_valid_displacement_print_proc (fail by default). Always returns the argument (p). Uninteresting in the all-interior-pointers mode. Note that we do not acquire the allocator lock, since nothing relevant about the header should change while we have a valid object pointer to the block.