GC_is_visible

Function GC_is_visible 

pub unsafe extern "C" fn GC_is_visible(
    arg1: *mut c_void,
) -> *mut c_void
Check that p is visible to the collector as a possibly pointer containing location. If it is not, call GC_is_visible_print_proc (fail by default). Always returns the argument (p). May erroneously succeed in hard cases. The function is intended for debugging use with untyped allocations. (The idea is that it should be possible, though slow, to add such a call to all indirect pointer stores.) Currently almost useless for the multi-threaded worlds.