GC_malloc

Function GC_malloc 

pub unsafe extern "C" fn GC_malloc(arg1: usize) -> *mut c_void
General-purpose allocation functions, with roughly malloc calling conventions. The atomic variants promise that no relevant pointers are contained in the object. The non-atomic variants guarantee that the new object is cleared. GC_malloc_uncollectable() allocates an object that is scanned for pointers to collectible objects, but is not itself collectible. The object is scanned even if it does not appear to be reachable. GC_malloc_uncollectable(), GC_free() (and GC_freezero()) called on the resulting object implicitly update GC_non_gc_bytes appropriately. All these functions (GC_malloc, GC_malloc_atomic, GC_strdup, GC_strndup, GC_malloc_uncollectable) are guaranteed never to return NULL unless GC_oom_fn() returns NULL.