GC_malloc_atomic_uncollectable

Function GC_malloc_atomic_uncollectable 

pub unsafe extern "C" fn GC_malloc_atomic_uncollectable(
    arg1: usize,
) -> *mut c_void
Allocate lb bytes of pointer-free, untraced, uncollectible data. This is normally roughly equivalent to the system malloc. But it may be useful if malloc is redefined. The function (including its debug variant) is guaranteed never to return NULL unless GC_oom_fn() returns NULL. Defined only if the library has been compiled with GC_ATOMIC_UNCOLLECTABLE macro defined.