GC_memalign

Function GC_memalign 

pub unsafe extern "C" fn GC_memalign(
    arg1: usize,
    arg2: usize,
) -> *mut c_void
The allocation function which guarantees the requested alignment of the allocated memory object. The align argument should be nonzero and a power of two. It is guaranteed never to return NULL unless GC_oom_fn() returns NULL.