GC_move_disappearing_link

Function GC_move_disappearing_link 

pub unsafe extern "C" fn GC_move_disappearing_link(
    arg1: *mut *mut c_void,
    arg2: *mut *mut c_void,
) -> c_int
Moves a link previously registered via GC_general_register_disappearing_link (or GC_register_disappearing_link). Does not change the target object of the weak reference. Does not change contents of *new_link. May be called with new_link equal to link (to check whether link has been registered). Returns GC_SUCCESS on success, GC_DUPLICATE if there is already another disappearing link at the new location (never returned if new_link is equal to link), GC_NOT_FOUND if no link is registered at the original location.