GC_posix_memalign

Function GC_posix_memalign 

pub unsafe extern "C" fn GC_posix_memalign(
    arg1: *mut *mut c_void,
    arg2: usize,
    arg3: usize,
) -> c_int
A function similar to GC_memalign but existing largely for redirection in the find-leak mode. The align argument should be nonzero and a power of two, but additionally the argument is required to be not less than size of a pointer. Note that the function does not change value of *memptr in case of failure (i.e. when the result is nonzero). It is guaranteed never to return NULL unless GC_oom_fn() returns NULL.