GC_pre_incr

Function GC_pre_incr 

pub unsafe extern "C" fn GC_pre_incr(
    arg1: *mut *mut c_void,
    arg2: isize,
) -> *mut c_void
Checked pointer pre- and post-increment operations. Note that the second argument (how_much) is in units of bytes, not multiples of the object size. This should either be invoked from a macro, or the call should be automatically generated.