GC_register_altstack

Function GC_register_altstack 

pub unsafe extern "C" fn GC_register_altstack(
    arg1: *mut c_void,
    arg2: usize,
    arg3: *mut c_void,
    arg4: usize,
)
Notify the collector about the stack and the alt-stack of the current thread. normstack and normstack_size are used to determine the “normal” stack boundaries when a thread is suspended while it is on an alt-stack. Acquires the allocator lock in the reader mode.