pub unsafe extern "C" fn GC_register_finalizer_no_order(
arg1: *mut c_void,
arg2: GC_finalization_proc,
arg3: *mut c_void,
arg4: *mut GC_finalization_proc,
arg5: *mut *mut c_void,
)Expand description
Another variant of GC_register_finalizer which ignores all cycles.
It should probably only be used by Java implementations. Note that
cd will still be viewed as accessible, even if it refers to the
object itself.