GC_set_interrupt_finalizers

Function GC_set_interrupt_finalizers 

pub unsafe extern "C" fn GC_set_interrupt_finalizers(arg1: c_uint)
Set maximum amount of finalizers to run during a single invocation of GC_invoke_finalizers(). Zero means no limit. Both the setter and the getter acquire the allocator lock (in the reader mode in case of the getter). Note that invocation of GC_finalize_all() resets the maximum amount value.