GC_set_manual_vdb_allowed

Function GC_set_manual_vdb_allowed 

pub unsafe extern "C" fn GC_set_manual_vdb_allowed(arg1: c_int)
Select whether to use the manual VDB (virtual dirty bits) mode for the incremental collection. Has no effect if called after enabling the incremental collection. The default value is off unless the collector is compiled with MANUAL_VDB macro defined. The manual VDB mode should be used only if the client has the appropriate GC_END_STUBBORN_CHANGE() and GC_reachable_here() (or, alternatively, GC_PTR_STORE_AND_DIRTY()) calls (to ensure proper write barriers). The setter and the getter are not synchronized.