GC_set_markers_count

Function GC_set_markers_count 

pub unsafe extern "C" fn GC_set_markers_count(arg1: c_uint)
Set the number of marker threads (including the initiating one) to the desired value at start-up. Zero value means the collector is to decide. If the correct nonzero value is passed, then GC_parallel will be set to the value minus one later. Has no effect if called after the collector initialization. Does not itself cause creation of the marker threads. Does not use any synchronization.