GC_set_max_heap_size

Function GC_set_max_heap_size 

pub unsafe extern "C" fn GC_set_max_heap_size(arg1: GC_word)
Limit the heap size to n bytes. Useful when you are debugging, especially on systems that do not handle running out of memory well. A zero n means the heap is unbounded; this is the default. This setter function is unsynchronized (so it might require GC_call_with_alloc_lock to avoid data race).