GC_set_mprotect_vdb_allowed

Function GC_set_mprotect_vdb_allowed 

pub unsafe extern "C" fn GC_set_mprotect_vdb_allowed(arg1: c_int)
Select whether to allow usage of the mprotect-based VDB (virtual dirty bits) mode for the incremental collection. The default value is on regardless of the availability of this VDB mode. Disallowing the mprotect-based VDB might be useful for applications that use mprotect() and/or SIGSEGV/SIGBUS for own needs or cannot deal with the related unintended system call failures. Has no effect if called after enabling the incremental collection (either explicitly or implicitly during the collector initialization). The setter and the getter are not synchronized.