GC_set_pages_executable

Function GC_set_pages_executable 

pub unsafe extern "C" fn GC_set_pages_executable(arg1: c_int)
Set whether the garbage collector will allocate executable memory pages or not. A nonzero argument instructs the collector to allocate memory with the executable flag on. Must be called before the collector is initialized. May have no effect on some platforms. The default value is controlled by NO_EXECUTE_PERMISSION macro (if present then the flag is off). Portable clients should have GC_set_pages_executable(1) call (before GC_INIT() one) provided they are going to execute code on any of the GC-allocated memory objects.