GC_set_suspend_signal

Function GC_set_suspend_signal 

pub unsafe extern "C" fn GC_set_suspend_signal(arg1: c_int)
Suggest the collector to use the specific signal to suspend threads. Has no effect after the collector initialization and on non-POSIX systems.