GC_set_thr_restart_signal

Function GC_set_thr_restart_signal 

pub unsafe extern "C" fn GC_set_thr_restart_signal(arg1: c_int)
Suggest the collector to use the specific signal to resume threads. Has no effect after the collector initialization and on non-POSIX systems. The same signal might be used for threads suspension and restart.