GC_set_time_limit_tv

Function GC_set_time_limit_tv 

pub unsafe extern "C" fn GC_set_time_limit_tv(arg1: GC_timeval_s)
Set/get the time limit of the incremental collections. This is similar to GC_set_time_limit and GC_get_time_limit but the time is provided with the nanosecond precision. The value of tv_nsec part should be less than a million. If the value of tv_ms part is GC_TIME_UNLIMITED, then tv_nsec part is ignored. Initially, the value of tv_nsec part of the time limit is zero. The functions do not use any synchronization. Defined only if the library has been compiled without NO_CLOCK macro defined.