GC_set_toggleref_func

Function GC_set_toggleref_func 

pub unsafe extern "C" fn GC_set_toggleref_func(
    arg1: GC_toggleref_func,
)
Set (register) a callback that decides the state of a given object (by, probably, inspecting its native state). The argument may be 0 (means no callback). Both the setter and the getter acquire the allocator lock (in the reader mode in case of the getter).