pub type GC_abort_func = Option<unsafe extern "C" fn(arg1: *const c_char)>;Expand description
This is invoked on the collector fatal aborts (just before
OS-dependent abort() or exit(1) is called). Must be non-NULL.
The default one outputs msg to the platform stderr provided
msg is non-NULL. msg is NULL if invoked before exit(1)
otherwise msg is non-NULL (i.e., if invoked before abort).
Both the setter and the getter acquire the allocator lock (in the reader
mode in case of the getter). The setter does not change GC_abort_func
if the library has been compiled with SMALL_CONFIG macro defined.
Aliased Type
pub enum GC_abort_func {
None,
Some(unsafe extern "C" fn(*const i8)),
}