GC_await_finalize_proc

Type Alias GC_await_finalize_proc 

pub type GC_await_finalize_proc = Option<unsafe extern "C" fn(arg1: *mut c_void)>;
Finalizer callback support. Invoked by the collector (with the allocator lock held) for each unreachable object enqueued for finalization. Zero means no callback. The setter and the getter acquire the allocator lock too (in the reader mode in case of the getter).

Aliased Type

pub enum GC_await_finalize_proc {
    None,
    Some(unsafe extern "C" fn(*mut c_void)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void))

Some value of type T.