GC_finalizer_notifier_proc

Type Alias GC_finalizer_notifier_proc 

pub type GC_finalizer_notifier_proc = Option<unsafe extern "C" fn()>;
Invoked by the collector when there are objects to be finalized. Invoked at most once per collection cycle. Never invoked unless GC_finalize_on_demand is set. Typically this will notify a finalization thread, which will call GC_invoke_finalizers() in response. May be 0 (means no notifier). Both the setter and the getter acquire the allocator lock (in the reader mode in case of the getter).

Aliased Type

pub enum GC_finalizer_notifier_proc {
    None,
    Some(unsafe extern "C" fn()),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn())

Some value of type T.