pub unsafe extern "C" fn GC_allow_register_threads()Expand description
Explicitly enable GC_register_my_thread() invocation.
Done implicitly if a GC thread-creation function is called
(or implicit thread registration is activated, or the collector is
compiled with GC_ALWAYS_MULTITHREADED macro defined). Otherwise,
it must be called from the main (or any previously registered)
thread between the collector initialization and the first explicit
registering of a thread (it should be called as late as possible).
Includes a GC_start_mark_threads() call.