pub unsafe extern "C" fn GC_enable_incremental()Expand description
Enable incremental/generational collection. Not advisable unless
dirty bits are available or most heap objects are pointer-free
(atomic) or immutable. Do not use in the find-leak mode.
Ignored if GC_dont_gc is nonzero. Only the generational piece of
this is functional if GC_time_limit is set to GC_TIME_UNLIMITED.
Causes thread-local variant of GC_gcj_malloc() to revert to locked
allocation. Must be called before any such GC_gcj_malloc() calls.
For best performance, should be called as early as possible.
On some platforms, calling it later may have adverse effects.
Safe to call before the collector initialization; it performs the
latter if not done yet.