pub unsafe extern "C" fn GC_end_stubborn_change(arg1: *const c_void)Expand description
Inform the collector that the object has been changed.
Only non-NULL pointer stores into the object are considered to be
changes. Matters only if the incremental collection is enabled in
the manual VDB (virtual dirty bits) mode; otherwise the function
does nothing. Should be followed typically by GC_reachable_here()
called for each of the stored pointers.