pub unsafe extern "C" fn GC_exclude_static_roots(
arg1: *mut c_void,
arg2: *mut c_void,
)Expand description
Inform the collector that a certain section of statically allocated
memory contains no pointers to garbage-collected memory. Thus it does
not need to be scanned. This is sometimes important if the application
maps large read/write files into the address space, which could be
mistaken for dynamic library data segments on some systems.
Both section start (low_address) and end (high_address_plus_1)
are not needed to be pointer-aligned.