pub unsafe extern "C" fn GC_foreach_heap_section_inner(
fn_: GC_heap_section_proc,
client_data: *mut c_void,
)Expand description
Apply fn to each heap section and each heap block inside.
Similar to GC_apply_to_all_blocks(). Assumes the allocator lock
is held at least in the reader mode, but no assertion about it
by design. Defined only if the library has been compiled without
NO_DEBUGGING macro defined.