pub unsafe extern "C" fn GC_freezero(arg1: *mut c_void, arg2: usize)Expand description
Similar to GC_free but also clears the object before deallocation.
Guaranteed to clear the specified amount of bytes from the beginning of
the deallocated object. It is safe to pass a value larger than the size
of the object, e.g. ~0 could be passed to clear the entire object.