pub unsafe extern "C" fn GC_get_avg_stopped_mark_time_ns() -> c_ulongExpand description
Get the average time spent in all mark phases with the world stopped.
The average value is computed since the start of the performance
measurements (or right since the collector initialization if the
collector logging is enabled). The result is in nanoseconds.
The function acquires the allocator lock (in the reader mode) to avoid
data race. Defined only if the library has been compiled without
NO_CLOCK macro defined.