pub unsafe extern "C" fn GC_get_prof_stats(
arg1: *mut GC_prof_stats_s,
arg2: usize,
) -> usizeExpand description
Atomically get the collector statistics (various global counters).
Clients should pass the size of the buffer (of GC_prof_stats_s type)
to fill in the values - this is for interoperability between different
collector versions: an old client could have fewer fields, and vice
versa, client could use newer gc.h file (with more entries declared
in the structure) than that of the linked collector library; in the
latter case, unsupported (unknown) fields are filled in with -1 (~0).
Return the size (in bytes) of the filled in part of the structure
(excluding all unknown fields, if any).