pub unsafe extern "C" fn GC_is_heap_ptr(arg1: *const c_void) -> c_intExpand description
Return 1 (true) if the argument points to somewhere in the garbage
collected heap, 0 otherwise. Primary use is as a fast alternative to
GC_base_C() to check whether the given object is allocated by the
collector or not. It is assumed that the collector is already initialized.