pub unsafe extern "C" fn GC_set_allocd_bytes_per_finalizer(
arg1: GC_word,
)Expand description
Set/get the minimum value of the ratio of allocated bytes since
garbage collection to the amount of finalizers created since that
collection (so value is greater than
GC_bytes_allocd / (GC_fo_entries - last_fo_entries)) which
triggers the collection instead heap expansion. The value has no
effect in the collector incremental mode. The default value is
10000 unless GC_ALLOCD_BYTES_PER_FINALIZER macro with a custom value
is defined to build the collector. The default value might be not the
right choice for clients where e.g. most objects have a finalizer.
Zero value effectively disables taking amount of finalizers in the
decision whether to collect or not. The functions do not use any
synchronization.