pub unsafe extern "C" fn GC_set_disable_automatic_collection(
arg1: c_int,
)Expand description
Control whether to disable algorithm deciding if a collection should be started when we allocated enough to amortize the collection. Both the setter and the getter acquire the allocator lock (in the reader mode in case of the getter) to avoid data race.