pub unsafe extern "C" fn GC_size(arg1: *const c_void) -> usizeExpand description
Given a pointer to the base of an object, return its size in bytes.
(For small objects this also happens to work from interior pointers,
but that should not be relied upon.) The returned size may be slightly
larger than the actual size of the object (the returned value may include
the size of the object debug header, an extra byte past end of the object,
etc.). The argument may be NULL (causing 0 to be returned).