pub unsafe extern "C" fn GC_start_performance_measurement()Expand description
Tell the collector to start various performance measurements.
Only the total time taken by full collections and the average time
spent in the world-stopped collections are calculated, as of now.
And, currently, there is no way to stop the measurements.
The function does not use any synchronization. Defined only if the
library has been compiled without NO_CLOCK macro defined.