#[repr(C)]pub struct GC_prof_stats_s {
pub heapsize_full: GC_word,
pub free_bytes_full: GC_word,
pub unmapped_bytes: GC_word,
pub bytes_allocd_since_gc: GC_word,
pub allocd_bytes_before_gc: GC_word,
pub non_gc_bytes: GC_word,
pub gc_no: GC_word,
pub markers_m1: GC_word,
pub bytes_reclaimed_since_gc: GC_word,
pub reclaimed_bytes_before_gc: GC_word,
pub expl_freed_bytes_since_gc: GC_word,
pub obtained_from_os_bytes: GC_word,
}Expand description
Structure used to query the GC statistics (profiling information). More fields could be added in the future. To preserve compatibility new fields should be added only to the end, and no deprecated fields should be removed from.
Fields
heapsize_full: GC_wordHeap size in bytes (including the area unmapped to OS).
Same as value of GC_get_heap_size() + GC_get_unmapped_bytes().
free_bytes_full: GC_wordTotal bytes contained in free and unmapped blocks.
Same as result of GC_get_free_bytes() + GC_get_unmapped_bytes().
unmapped_bytes: GC_wordAmount of memory unmapped to OS. Same as the value returned by
GC_get_unmapped_bytes().
bytes_allocd_since_gc: GC_wordNumber of bytes allocated since the recent collection.
Same as the value returned by GC_get_bytes_since_gc().
allocd_bytes_before_gc: GC_wordNumber of bytes allocated before the recent garbage collection.
The value may wrap. Same as the result of
GC_get_total_bytes() - GC_get_bytes_since_gc().
non_gc_bytes: GC_wordNumber of bytes not considered candidates for garbage collection.
Same as the value returned by GC_get_non_gc_bytes().
gc_no: GC_wordGarbage collection cycle number. The value may wrap. Same as the
value returned by GC_get_gc_no().
markers_m1: GC_wordNumber of marker threads (excluding the initiating one). Same as
the value returned by GC_get_parallel() (or 0 if the collector
is single-threaded).
bytes_reclaimed_since_gc: GC_wordApproximate number of reclaimed bytes after the recent garbage collection.
reclaimed_bytes_before_gc: GC_wordApproximate number of bytes reclaimed before the recent garbage collection. The value may wrap.
expl_freed_bytes_since_gc: GC_wordNumber of bytes freed explicitly since the recent garbage collection.
Same as the value returned by GC_get_expl_freed_bytes_since_gc().
obtained_from_os_bytes: GC_wordTotal amount of memory obtained from OS, in bytes.