pub type GC_await_finalize_proc = Option<unsafe extern "C" fn(arg1: *mut c_void)>;Expand description
Finalizer callback support. Invoked by the collector (with the allocator lock held) for each unreachable object enqueued for finalization. Zero means no callback. The setter and the getter acquire the allocator lock too (in the reader mode in case of the getter).
Aliased Type
pub enum GC_await_finalize_proc {
None,
Some(unsafe extern "C" fn(*mut c_void)),
}