pub type GC_finalizer_notifier_proc = Option<unsafe extern "C" fn()>;Expand description
Invoked by the collector when there are objects to be finalized.
Invoked at most once per collection cycle. Never invoked unless
GC_finalize_on_demand is set. Typically this will notify
a finalization thread, which will call GC_invoke_finalizers() in
response. May be 0 (means no notifier). Both the setter and the getter
acquire the allocator lock (in the reader mode in case of the getter).
Aliased Type
pub enum GC_finalizer_notifier_proc {
None,
Some(unsafe extern "C" fn()),
}