pub type GC_toggleref_func = Option<unsafe extern "C" fn(arg1: *mut c_void) -> GC_ToggleRefStatus>;Expand description
The callback is to decide (return) the new state of a given object. Invoked by the collector for all objects registered for “toggle-refs” processing. Invoked with the allocator lock held but the world is running.
Aliased Type
pub enum GC_toggleref_func {
None,
Some(unsafe extern "C" fn(*mut c_void) -> u32),
}