pub type GC_warn_proc = Option<unsafe extern "C" fn(arg1: *const c_char, arg2: GC_uintptr_t)>;Expand description
GC_set_warn_proc can be used to redirect or filter warning messages.
p may not be a NULL pointer. msg is a printf format string
(arg must match the format). Both the setter and the getter acquire
the allocator lock (in the reader mode in case of the getter) to avoid
data race. In GC v7.1 and before: the setter returned the value of
old warn_proc. In GC v8.2.x and before: msg pointer type had
no const qualifier.
Aliased Type
pub enum GC_warn_proc {
None,
Some(unsafe extern "C" fn(*const i8, u64)),
}