pub type GC_word = c_ulong;
Define public word and signed_word to be unsigned and signed types of the size same as of size_t, ptrdiff_t, and of the address part of data pointers (like char * and void *).
word
signed_word
size_t
ptrdiff_t
char *
void *